==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_th_TH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="th_TH" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>อุปกรณ์ยังไม่พร้อม</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>ส่งวิดีโอล่าสุดทางอีเมล</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>ส่งวิดีโอไปยังอีเมล</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>ส่ง</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>วิดีโอดังแนบ</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>เลือกไฟล์อย่างน้อยหนึ่งไฟล์</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>มีขอบ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>อุปกรณ์ยังไม่พร้อม</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>เต็มจอ</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>หน้าต่าง</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>พื้นที่</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>แนบติด</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>เสียง</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>ค่าปริยาย</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>ตัวถอดรหัส</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>ไม่ต้องแสดงเคอร์เซอร์</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>พาธของวิดีโอ</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>เครื่องเล่น</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>ย่อหน้าต่างขณะทำการบันทึก</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>เริ่ม</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>หยุด</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>หยุดชั่วคราว</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>เล่น</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>ส่ง</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>เวลาที่ใช้บันทึก</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>ขนาดเป็นกิโลไบต์</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>ขนาดของหน้าจอ</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>รูปแบบ</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>กำหนดค่าเฟรมต่อวินาที</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>เปิดไดเร็คทอรี่</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>นับถอยหลัง</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>เล่นวิดีโอล่าสุด</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>ส่งวิดีโอ</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>เลือกอุปกรณ์</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>จำนวนเฟรมต่อวินาที</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>ไป</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>โฮมเพจ</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>จดหมายเวียน</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>ซัพพอร์ต</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>ผู้พัฒนา</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>เฟรม</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>เบต้าใน openSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>บริจาค</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>โปรแกรมสำหรับบันทึก</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>การแปล</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>รหัสต้นฉบับ</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>แสดงในถาดระบบ</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>มีรุ่นใหม่</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>ตัวถอดรหัสวิดีโอ</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>ตัวถอดรหัสเสียง</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>เว็บแคม</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>เลือกเว็บแคม</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_th_TH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="th_TH" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>อุปกรณ์ยังไม่พร้อม</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>ส่งวิดีโอล่าสุดทางอีเมล</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>ส่งวิดีโอไปยังอีเมล</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>ส่ง</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>วิดีโอดังแนบ</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>เลือกไฟล์อย่างน้อยหนึ่งไฟล์</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>มีขอบ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>อุปกรณ์ยังไม่พร้อม</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>เต็มจอ</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>หน้าต่าง</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>พื้นที่</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>แนบติด</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>เสียง</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>ค่าปริยาย</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>ตัวถอดรหัส</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>ไม่ต้องแสดงเคอร์เซอร์</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>พาธของวิดีโอ</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>เครื่องเล่น</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>ย่อหน้าต่างขณะทำการบันทึก</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>เริ่ม</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>หยุด</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>หยุดชั่วคราว</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>เล่น</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>ส่ง</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>เวลาที่ใช้บันทึก</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>ขนาดเป็นกิโลไบต์</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>ขนาดของหน้าจอ</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>รูปแบบ</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>กำหนดค่าเฟรมต่อวินาที</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>เปิดไดเร็คทอรี่</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>นับถอยหลัง</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>เล่นวิดีโอล่าสุด</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>ส่งวิดีโอ</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>เลือกอุปกรณ์</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>จำนวนเฟรมต่อวินาที</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>ไป</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>โฮมเพจ</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>ซัพพอร์ต</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>ผู้พัฒนา</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>เฟรม</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>บริจาค</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>โปรแกรมสำหรับบันทึก</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>การแปล</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>รหัสต้นฉบับ</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>แสดงในถาดระบบ</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>มีรุ่นใหม่</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>ตัวถอดรหัสวิดีโอ</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>ตัวถอดรหัสเสียง</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>เว็บแคม</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>เลือกเว็บแคม</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
